==> haskell-semirings-0.6-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semirings
version:              0.6
visibility:           public
id:                   semirings-0.6-5G7txqHKZTWLq32nYcIqGO
key:                  semirings-0.6-5G7txqHKZTWLq32nYcIqGO
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  74a4e503ce3a597800778cde6580fe0a
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Semiring Data.Semiring.Generic
    Data.Semiring.Tropical Data.Star

import-dirs:          /usr/lib/ghc-9.4.8/site-local/semirings-0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/semirings-0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/semirings-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.6-5G7txqHKZTWLq32nYcIqGO
depends:
    base-4.17.2.1 base-compat-batteries-0.12.3-C5jngX22QEvHWFs7vjiyaK
    containers-0.6.7 hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    unordered-containers-0.2.20-3jxCiK1Dn5HHqgJhQ3B9SH

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semirings-0.6-198-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semirings
version:              0.6
visibility:           public
id:                   semirings-0.6-327yJtZC5PU4wWaoept1as
key:                  semirings-0.6-327yJtZC5PU4wWaoept1as
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  cf5b836a4d1425293f5d089586ae16ec
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Semiring Data.Semiring.Generic
    Data.Semiring.Tropical Data.Star

import-dirs:          /usr/lib/ghc-9.4.8/site-local/semirings-0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/semirings-0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/semirings-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.6-327yJtZC5PU4wWaoept1as
depends:
    base-4.17.2.1 base-compat-batteries-0.12.3-C5jngX22QEvHWFs7vjiyaK
    containers-0.6.7 hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
